@@ -34,24 +34,37 @@ setMethod(f = 'writeWeatherRecords',
             stop(sprintf('The output files are not equal to %s', 
                 object@num))
         }
-        var_name <- c('year', 'day', 'radn','maxt', 'mint', 'rain', 'evap', 'vp', 'code')
-        var_unit <- c('()', '()', '(mj/m2)', '(oC)', '(oC)', '(mm)', '(mm)', '(hPa)', '()')
-        var_width <- c(4, 5, 6, 6, 6, 6, 6, 6, 7)
-        nsmall <- c(0, 0, 0, 0, 0, 0, 0, 0, 0)
-        var_cols <- c('year', 'day', 'radn', 'maxt', 'mint', 'rain', 'evap', 'vp', 'code')
-        if (!is.null(cols)) {
-            cols <- unique(c('year', 'day', cols))
-            pos <- var_cols %in% cols
-            var_cols <- var_cols[pos]
-            var_name <- var_name[pos]
-            var_unit <- var_unit[pos]
-            var_width <- var_width[pos]
-            nsmall <- nsmall[pos]
-        }
+        
         for (i in seq(length = object@num))
         {
             records <- getWeaAnaSiteByPos(object, i)
             records <- records$value
+            
+            if (!is.null(records@extra) && 
+                !is.null(records@extra$rhmint) && 
+                !is.null(records@extra$rhmaxt)) {
+                var_name <- c('year', 'day', 'radn','maxt', 'mint', 'rain', 'evap', 'vp', "rhmint", "rhmaxt", 'code')
+                var_unit <- c('()', '()', '(mj/m2)', '(oC)', '(oC)', '(mm)', '(mm)', '(hPa)', "(%)", "(%)", '()')
+                var_width <- c(4, 5, 6, 6, 6, 6, 6, 6, 6, 6, 7)
+                nsmall <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
+                var_cols <- c('year', 'day', 'radn', 'maxt', 'mint', 'rain', 'evap', 'vp', "rhmint", "rhmaxt", 'code')
+            } else {
+                var_name <- c('year', 'day', 'radn','maxt', 'mint', 'rain', 'evap', 'vp', 'code')
+                var_unit <- c('()', '()', '(mj/m2)', '(oC)', '(oC)', '(mm)', '(mm)', '(hPa)', '()')
+                var_width <- c(4, 5, 6, 6, 6, 6, 6, 6, 7)
+                nsmall <- c(0, 0, 0, 0, 0, 0, 0, 0, 0)
+                var_cols <- c('year', 'day', 'radn', 'maxt', 'mint', 'rain', 'evap', 'vp', 'code')
+            }
+            if (!is.null(cols)) {
+                cols <- unique(c('year', 'day', cols))
+                pos <- var_cols %in% cols
+                var_cols <- var_cols[pos]
+                var_name <- var_name[pos]
+                var_unit <- var_unit[pos]
+                var_width <- var_width[pos]
+                nsmall <- nsmall[pos]
+            }
+            
             res_str <- NULL
             res_str <- c(res_str, 
                 sprintf('!station number = %s', 
@@ -78,10 +91,14 @@ setMethod(f = 'writeWeatherRecords',
             pos <- NULL
             for (j in seq(along = var_cols))
             {
-                if (length(methods::slot(records, var_cols[j])) > 0)
+                if (var_cols[j] %in% c("rhmint", "rhmaxt")) {
+                    v <- methods::slot(records, "extra")[[var_cols[j]]]
+                } else {
+                    v <- methods::slot(records, var_cols[j])
+                }
+                if (length(v) > 0)
                 {
-                    values[[var_cols[j]]] <- format(
-                        methods::slot(records, var_cols[j]), 
+                    values[[var_cols[j]]] <- format(v, 
                         width = var_width[j], justify = 'right',
                         nsmall = nsmall[j])
                     pos <- c(pos, j)
